.. webapi-error::
   :title: OAuth2 Missing Scope Error
   :instance: djblets.webapi.errors.OAUTH_MISSING_SCOPE_ERROR

   The OAuth2 token being used lacks the necessary scopes for the given
   request.
